@@ -145,6 +145,10 @@ atk_role_get_type (void)
       { ATK_ROLE_DESCRIPTION_TERM, "ATK_ROLE_DESCRIPTION_TERM", "description-term" },
       { ATK_ROLE_DESCRIPTION_VALUE, "ATK_ROLE_DESCRIPTION_VALUE", "description-value" },
       { ATK_ROLE_STATIC, "ATK_ROLE_STATIC", "static" },
+      { ATK_ROLE_MATH_FRACTION, "ATK_ROLE_MATH_FRACTION", "math-fraction" },
+      { ATK_ROLE_MATH_ROOT, "ATK_ROLE_MATH_ROOT", "math-root" },
+      { ATK_ROLE_SUBSCRIPT, "ATK_ROLE_SUBSCRIPT", "subscript" },
+      { ATK_ROLE_SUPERSCRIPT, "ATK_ROLE_SUPERSCRIPT", "superscript" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
